@@ -104,6 +104,10 @@ def setup_resources(feature):
     assert batch_anomaly_scores['code'] == HTTP_OK
     world.init_batch_anomaly_scores_count = batch_anomaly_scores['meta']['total_count']
 
+    projects = world.api.list_projects()
+    assert projects['code'] == HTTP_OK
+    world.init_projects_count = projects['meta']['total_count']
+
     world.sources = []
     world.datasets = []
     world.models = []
@@ -117,6 +121,7 @@ def setup_resources(feature):
     world.anomalies = []
     world.anomaly_scores = []
     world.batch_anomaly_scores = []
+    world.projects = []
 
     world.dataset_ids = []
     world.fields_properties_dict = {}
@@ -166,6 +171,9 @@ def cleanup_resources(feature):
     delete(world.batch_anomaly_scores, world.api.delete_batch_anomaly_score)
     world.batch_anomaly_scores = []
 
+    delete(world.projects, world.api.delete_project)
+    world.projects = []
+
     sources = world.api.list_sources()
     assert sources['code'] == HTTP_OK
     world.final_sources_count = sources['meta']['total_count']
@@ -218,6 +226,10 @@ def cleanup_resources(feature):
     assert batch_anomaly_scores['code'] == HTTP_OK
     world.final_batch_anomaly_scores_count = batch_anomaly_scores['meta']['total_count']
 
+    projects = world.api.list_projects()
+    assert projects['code'] == HTTP_OK
+    world.final_projects_count = projects['meta']['total_count']
+
     assert world.final_sources_count == world.init_sources_count, "init: %s, final: %s" % (world.init_sources_count, world.final_sources_count)
     assert world.final_datasets_count == world.init_datasets_count, "init: %s, final: %s" % (world.init_datasets_count, world.final_datasets_count)
     assert world.final_models_count == world.init_models_count, "init: %s, final: %s" % (world.init_models_count, world.final_models_count)
@@ -231,6 +243,7 @@ def cleanup_resources(feature):
     assert world.final_anomalies_count == world.init_anomalies_count, "init: %s, final: %s" % (world.init_anomalies_count, world.final_anomalies_count)
     assert world.final_anomaly_scores_count == world.init_anomaly_scores_count, "init: %s, final: %s" % (world.init_anomaly_scores_count, world.final_anomaly_scores_count)
     assert world.final_batch_anomaly_scores_count == world.init_batch_anomaly_scores_count, "init: %s, final: %s" % (world.init_batch_anomaly_scores_count, world.final_batch_anomaly_scores_count)
+    assert world.final_projects_count == world.init_projects_count, "init: %s, final: %s" % (world.init_projects_count, world.final_projects_count)
 
 
 @after.each_scenario
